@@ -62,17 +62,25 @@ class PaymentsManager(LocalData):
 class NotificationsManager(LocalData):
     file_source = "notifications.yaml"
 
-    def folio(self, serie):
-        return self["Series"][serie]
+    def folio(self):
+        return self["Folio"]
 
-    def set_folio(self, serie: str, folio: int):
-        self["Series"][serie] = max(self["Series"][serie], folio + 1)
+    def serie(self):
+        return self["Serie"]
+
+    def set_folio(self, folio: int):
+        self["Folio"] = folio
         self.save()
 
 
 class ClientsManager(LocalData):
     file_source = "clients.yaml"
 
+    def __init__(self):
+        super().__init__()
+        for k in self:
+            self[k]["Rfc"] = k
+
 
 class FacturasManager(dict):
     def __init__(self, values, file_source="facturas.yaml"):
